@@ -4,13 +4,13 @@ var indexSectionsWithContent =
   1: "b",
   2: "bl",
   3: "b",
-  4: "abcdfhilmnoprstuvx",
+  4: "abcdefghilmnoprstuvx",
   5: "b",
   6: "b",
   7: "bc",
   8: "ac",
   9: "abcdefgilmoprstvw",
-  10: "02bcdefilmnrstuvw"
+  10: "02_abcdefghilmnprstuvw"
 };
 
 var indexSectionNames =
